public inbox for gdb-cvs@sourceware.org
help / color / mirror / Atom feed
From: Andrew Burgess <aburgess@sourceware.org>
To: gdb-cvs@sourceware.org
Subject: [binutils-gdb] gdb: update comments throughout reggroups.{c,h} files
Date: Thu,  7 Apr 2022 15:09:02 +0000 (GMT)	[thread overview]
Message-ID: <20220407150902.776F8385E019@sourceware.org> (raw)

https://sourceware.org/git/gitweb.cgi?p=binutils-gdb.git;h=524ad5e30fb66ee2f03547b2d9f5c67bccdc8534

commit 524ad5e30fb66ee2f03547b2d9f5c67bccdc8534
Author: Andrew Burgess <aburgess@redhat.com>
Date:   Thu Mar 31 18:19:23 2022 +0100

    gdb: update comments throughout reggroups.{c,h} files
    
    This commit updates the comments in the gdb/reggroups.{c,h} files.
    Fill in some missing comments, correct a few comments that were not
    clear, and where we had comments duplicated between .c and .h files,
    update the .c to reference the .h.
    
    No user visible changes after this commit.

Diff:
---
 gdb/reggroups.c | 11 +++++++++--
 gdb/reggroups.h | 14 ++++++++++++--
 2 files changed, 21 insertions(+), 4 deletions(-)

diff --git a/gdb/reggroups.c b/gdb/reggroups.c
index 42232811087..1a13cb2fba0 100644
--- a/gdb/reggroups.c
+++ b/gdb/reggroups.c
@@ -28,6 +28,8 @@
 #include "gdbcmd.h"		/* For maintenanceprintlist.  */
 #include "gdbsupport/gdb_obstack.h"
 
+/* See reggroups.h.  */
+
 const reggroup *
 reggroup_new (const char *name, enum reggroup_type type)
 {
@@ -82,9 +84,11 @@ private:
   std::vector<const struct reggroup *> m_groups;
 };
 
+/* Key used to lookup register group data from a gdbarch.  */
+
 static struct gdbarch_data *reggroups_data;
 
-/* Add GROUP to the list of register groups for GDBARCH.  */
+/* See reggroups.h.  */
 
 void
 reggroup_add (struct gdbarch *gdbarch, const reggroup *group)
@@ -128,7 +132,8 @@ gdbarch_reggroups (struct gdbarch *gdbarch)
   return groups->groups ();
 }
 
-/* Is REGNUM a member of REGGROUP?  */
+/* See reggroups.h.  */
+
 int
 default_register_reggroup_p (struct gdbarch *gdbarch, int regnum,
 			     const struct reggroup *group)
@@ -207,6 +212,8 @@ reggroups_dump (struct gdbarch *gdbarch, struct ui_file *file)
     }
 }
 
+/* Implement 'maintenance print reggroups' command.  */
+
 static void
 maintenance_print_reggroups (const char *args, int from_tty)
 {
diff --git a/gdb/reggroups.h b/gdb/reggroups.h
index 5f8a8a395b3..a2b4cc5713e 100644
--- a/gdb/reggroups.h
+++ b/gdb/reggroups.h
@@ -24,7 +24,17 @@
 
 struct gdbarch;
 
-enum reggroup_type { USER_REGGROUP, INTERNAL_REGGROUP };
+/* The different register group types.  */
+enum reggroup_type {
+  /* Used for any register group that should be visible to the user.
+     Architecture specific register groups, as well as most of the default
+     groups will have this type.  */
+  USER_REGGROUP,
+
+  /* Used for a few groups that GDB uses while managing machine state.
+     These groups are mostly hidden from the user.  */
+  INTERNAL_REGGROUP
+};
 
 /* Individual register group.  */
 
@@ -73,7 +83,7 @@ extern const reggroup *reggroup_gdbarch_new (struct gdbarch *gdbarch,
 					     const char *name,
 					     enum reggroup_type type);
 
 /* Add a register group (with attribute values) to the pre-defined list.  */
 extern void reggroup_add (struct gdbarch *gdbarch, const reggroup *group);
 
 /* Return the list of all register groups for GDBARCH.  */
@@ -73,7 +83,7 @@ extern const reggroup *reggroup_gdbarch_new (struct gdbarch *gdbarch,
 					     enum reggroup_type type);
 
-/* Add a register group (with attribute values) to the pre-defined list.  */
+/* Add register group GROUP to the list of register groups for GDBARCH.  */
 extern void reggroup_add (struct gdbarch *gdbarch, const reggroup *group);
 


                 reply	other threads:[~2022-04-07 15:09 UTC|newest]

Thread overview: [no followups] expand[flat|nested]  mbox.gz  Atom feed

Reply instructions:

You may reply publicly to this message via plain-text email
using any one of the following methods:

* Save the following mbox file, import it into your mail client,
  and reply-to-all from there: mbox

  Avoid top-posting and favor interleaved quoting:
  https://en.wikipedia.org/wiki/Posting_style#Interleaved_style

* Reply using the --to, --cc, and --in-reply-to
  switches of git-send-email(1):

  git send-email \
    --in-reply-to=20220407150902.776F8385E019@sourceware.org \
    --to=aburgess@sourceware.org \
    --cc=gdb-cvs@sourceware.org \
    /path/to/YOUR_REPLY

  https://kernel.org/pub/software/scm/git/docs/git-send-email.html

* If your mail client supports setting the In-Reply-To header
  via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line before the message body.
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox;
as well as URLs for read-only IMAP folder(s) and NNTP newsgroup(s).